define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "這一季",
	"field-quarter-short-relative+1": "下一季",
	"field-tue-relative+-1": "上週二",
	"field-year": "年",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "本週三",
	"field-wed-relative+1": "下週三",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "分鐘",
	"field-month-narrow-relative+-1": "上個月",
	"field-tue-narrow-relative+0": "本週二",
	"field-tue-narrow-relative+1": "下週二",
	"field-day-short-relative+-1": "昨天",
	"field-thu-short-relative+0": "本週四",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "今天",
	"field-day-short-relative+-2": "前天",
	"field-thu-short-relative+1": "下週四",
	"field-day-relative+1": "明天",
	"field-week-narrow-relative+0": "本週",
	"field-day-relative+2": "後天",
	"field-week-narrow-relative+1": "下週",
	"dateFormatItem-EBhms": "E Bh:mm:ss",
	"field-wed-narrow-relative+-1": "上週三",
	"field-year-narrow": "年",
	"field-era-short": "年代",
	"field-year-narrow-relative+0": "今年",
	"field-tue-relative+0": "本週二",
	"field-year-narrow-relative+1": "明年",
	"field-tue-relative+1": "下週二",
	"field-weekdayOfMonth": "每月平日",
	"field-second-short": "秒",
	"dateFormatItem-MMMd": "MMMd日",
	"field-weekdayOfMonth-narrow": "每月平日",
	"field-week-relative+0": "本週",
	"field-month-relative+0": "本月",
	"field-week-relative+1": "下週",
	"field-month-relative+1": "下個月",
	"field-sun-narrow-relative+0": "本週日",
	"field-mon-short-relative+0": "本週一",
	"field-sun-narrow-relative+1": "下週日",
	"field-mon-short-relative+1": "下週一",
	"field-second-relative+0": "現在",
	"dateFormatItem-yyyyQQQ": "rU年QQQQ",
	"months-standAlone-narrow": [
		"正",
		"二",
		"三",
		"四",
		"五",
		"六",
		"七",
		"八",
		"九",
		"十",
		"冬",
		"臘"
	],
	"field-weekOfMonth": "週",
	"field-month-short": "月",
	"dateFormatItem-GyMMMEd": "rU年MMMdE",
	"dateFormatItem-yyyyMd": "r年MMMd",
	"field-day": "日",
	"field-dayOfYear-short": "年天",
	"field-year-relative+-1": "去年",
	"field-sat-short-relative+-1": "上週六",
	"field-hour-relative+0": "這一小時",
	"dateFormatItem-yyyyMEd": "rU年MMMd，E",
	"field-second-short-relative+0": "現在",
	"field-wed-relative+-1": "上週三",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "上週六",
	"field-second": "秒",
	"dateFormat-long": "rU年MMMd",
	"dateFormatItem-GyMMMd": "r年MMMd",
	"field-hour-short-relative+0": "這一小時",
	"field-quarter": "季",
	"field-week-short": "週",
	"field-day-narrow-relative+0": "今天",
	"field-day-narrow-relative+1": "明天",
	"field-day-narrow-relative+2": "後天",
	"field-tue-short-relative+0": "本週二",
	"field-tue-short-relative+1": "下週二",
	"field-month-short-relative+-1": "上個月",
	"field-mon-relative+-1": "上週一",
	"dateFormatItem-GyMMM": "rU年MMM",
	"field-month": "月",
	"field-day-narrow": "日",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "分鐘",
	"field-dayperiod": "上午/下午",
	"field-sat-short-relative+0": "本週六",
	"field-sat-short-relative+1": "下週六",
	"dateFormat-medium": "r年MMMd",
	"dateFormatItem-yyyyMMMM": "rU年MMMM",
	"dateFormatItem-UMMM": "U年MMM",
	"dateFormatItem-yyyyM": "rU年MMM",
	"field-second-narrow": "秒",
	"field-mon-relative+0": "本週一",
	"field-day-narrow-relative+-1": "昨天",
	"field-year-short": "年",
	"field-mon-relative+1": "下週一",
	"field-day-narrow-relative+-2": "前天",
	"months-format-narrow": [
		"正",
		"二",
		"三",
		"四",
		"五",
		"六",
		"七",
		"八",
		"九",
		"十",
		"冬",
		"臘"
	],
	"field-quarter-relative+-1": "上一季",
	"dateFormatItem-yyyyMMMd": "r年MMMd",
	"field-dayperiod-narrow": "上午/下午",
	"field-week-narrow-relative+-1": "上週",
	"field-dayOfYear": "年天",
	"field-sat-relative+-1": "上週六",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "M/d",
	"field-hour": "小時",
	"field-minute-narrow-relative+0": "這一分鐘",
	"months-format-wide": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"冬月",
		"臘月"
	],
	"dateFormat-full": "rU年MMMd EEEE",
	"dateFormatItem-UMd": "U年MMMd",
	"field-month-relative+-1": "上個月",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "季",
	"field-sat-narrow-relative+0": "本週六",
	"field-fri-relative+0": "本週五",
	"field-sat-narrow-relative+1": "下週六",
	"field-fri-relative+1": "下週五",
	"dateFormatItem-EBhm": "E Bh:mm",
	"field-month-narrow-relative+0": "本月",
	"field-month-narrow-relative+1": "下個月",
	"field-sun-short-relative+0": "本週日",
	"field-sun-short-relative+1": "下週日",
	"field-week-relative+-1": "上週",
	"field-quarter-short-relative+-1": "上一季",
	"field-minute-short-relative+0": "這一分鐘",
	"months-format-abbr": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"冬月",
		"臘月"
	],
	"field-quarter-relative+0": "這一季",
	"field-minute-relative+0": "這一分鐘",
	"field-quarter-relative+1": "下一季",
	"field-wed-short-relative+-1": "上週三",
	"dateFormat-short": "r/M/d",
	"dateFormatItem-Bh": "Bh時",
	"field-year-narrow-relative+-1": "去年",
	"field-thu-short-relative+-1": "上週四",
	"dateFormatItem-yyyyMMMEd": "rU年MMMdE",
	"field-mon-narrow-relative+-1": "上週一",
	"dateFormatItem-MMMMd": "MMMMd日",
	"field-thu-narrow-relative+-1": "上週四",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "HH時",
	"field-weekOfMonth-short": "週",
	"field-tue-narrow-relative+-1": "上週二",
	"dateFormatItem-yyyy": "rU年",
	"dateFormatItem-M": "MMM",
	"months-standAlone-wide": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"冬月",
		"臘月"
	],
	"field-wed-short-relative+0": "本週三",
	"field-wed-short-relative+1": "下週三",
	"field-sun-relative+-1": "上週日",
	"dateTimeFormat-full": "{1} {0}",
	"field-second-narrow-relative+0": "現在",
	"dateFormatItem-hm": "ah:mm",
	"dateFormatItem-d": "d日",
	"field-weekday": "週天",
	"field-day-short-relative+0": "今天",
	"field-quarter-narrow-relative+0": "這一季",
	"field-day-short-relative+1": "明天",
	"field-sat-relative+0": "本週六",
	"field-quarter-narrow-relative+1": "下一季",
	"dateFormatItem-h": "ah時",
	"field-day-short-relative+2": "後天",
	"field-sat-relative+1": "下週六",
	"field-week-short-relative+0": "本週",
	"field-week-short-relative+1": "下週",
	"months-standAlone-abbr": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"冬月",
		"臘月"
	],
	"field-dayOfYear-narrow": "年天",
	"field-month-short-relative+0": "本月",
	"field-month-short-relative+1": "下個月",
	"field-weekdayOfMonth-short": "每月平日",
	"dateFormatItem-MEd": "M/dE",
	"field-zone-narrow": "時區",
	"dateFormatItem-y": "rU年",
	"field-thu-narrow-relative+0": "本週四",
	"field-sun-narrow-relative+-1": "上週日",
	"field-mon-short-relative+-1": "上週一",
	"field-thu-narrow-relative+1": "下週四",
	"field-thu-relative+0": "本週四",
	"field-thu-relative+1": "下週四",
	"dateFormatItem-hms": "ah:mm:ss",
	"field-fri-short-relative+-1": "上週五",
	"field-thu-relative+-1": "上週四",
	"dateFormatItem-yMd": "r年MMMd",
	"field-week": "週",
	"dateFormatItem-Ed": "d E",
	"field-wed-narrow-relative+0": "本週三",
	"field-wed-narrow-relative+1": "下週三",
	"field-quarter-narrow-relative+-1": "上一季",
	"field-year-short-relative+0": "今年",
	"dateFormatItem-yyyyMMM": "rU年MMM",
	"field-dayperiod-short": "上午/下午",
	"field-year-short-relative+1": "明年",
	"field-fri-short-relative+0": "本週五",
	"field-fri-short-relative+1": "下週五",
	"field-week-short-relative+-1": "上週",
	"field-hour-narrow-relative+0": "這一小時",
	"dateFormatItem-yyyyQQQQ": "rU年QQQQ",
	"dateFormatItem-UMMMd": "U年MMMd",
	"field-hour-short": "小時",
	"field-zone-short": "時區",
	"field-month-narrow": "月",
	"field-hour-narrow": "小時",
	"field-fri-narrow-relative+-1": "上週五",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "明年",
	"field-era-narrow": "年代",
	"field-fri-relative+-1": "上週五",
	"dateFormatItem-Bhms": "Bh:mm:ss",
	"field-tue-short-relative+-1": "上週二",
	"field-minute-narrow": "分鐘",
	"field-mon-narrow-relative+0": "本週一",
	"field-mon-narrow-relative+1": "下週一",
	"field-year-short-relative+-1": "去年",
	"field-zone": "時區",
	"dateFormatItem-MMMEd": "MMMd日E",
	"field-weekOfMonth-narrow": "週",
	"field-weekday-narrow": "週天",
	"field-quarter-narrow": "季",
	"field-sun-short-relative+-1": "上週日",
	"field-day-relative+-1": "昨天",
	"field-day-relative+-2": "前天",
	"field-weekday-short": "週天",
	"dateFormatItem-Bhm": "Bh:mm",
	"field-sun-relative+0": "本週日",
	"field-sun-relative+1": "下週日",
	"dateFormatItem-Gy": "rU年",
	"field-day-short": "日",
	"field-week-narrow": "週",
	"field-era": "年代",
	"field-fri-narrow-relative+0": "本週五",
	"dateFormatItem-UM": "U年MMM",
	"field-fri-narrow-relative+1": "下週五"
}
//end v1.x content
);